Minecraft Server Config
=======================

If you have experience of Minecraft Servers and want to make changes to
the defaults used by MCIWB then read on.

Configuration of the default server
-----------------------------------

Your server installation is created in ``$HOME/mciwb_server`` if you want to 
change the world settings then you can go into that folder and alter the
``server.properties``.

Perform the following to pick up the changes::

    mciwb stop
    mciwb start

Running your own Server
-----------------------

TODO